# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/private/v1/memos.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/private/v1/memos.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import memo_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_memo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1systemathics/apis/services/private/v1/memos.proto\x12%systemathics.apis.services.private.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a+systemathics/apis/type/shared/v1/memo.proto\"\xf2\x01\n\x0cMemosRequest\x12#\n\rsearch_string\x18\x01 \x01(\tR\x0csearchString\x12W\n\x0bsearch_type\x18\x02 \x01(\x0e\x32\x36.systemathics.apis.services.private.v1.MemosSearchTypeR\nsearchType\x12\x31\n\x05start\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05start\x12\x31\n\x05\x63ount\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05\x63ount\"h\n\rMemosResponse\x12<\n\x05memos\x18\x01 \x03(\x0b\x32&.systemathics.apis.type.shared.v1.MemoR\x05memos\x12\x19\n\x08has_more\x18\x02 \x01(\x08R\x07hasMore*\x80\x01\n\x0fMemosSearchType\x12!\n\x1dMEMOS_SEARCH_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1cMEMOS_SEARCH_TYPE_SUB_STRING\x10\x01\x12(\n$MEMOS_SEARCH_TYPE_REGULAR_EXPRESSION\x10\x02\x32\x96\x01\n\x0cMemosService\x12\x85\x01\n\x05Memos\x12\x33.systemathics.apis.services.private.v1.MemosRequest\x1a\x34.systemathics.apis.services.private.v1.MemosResponse\"\x11\x82\xd3\xe4\x93\x02\x0b\x12\t/v1/memosB\xf2\x01\n)com.systemathics.apis.services.private.v1B\nMemosProtoP\x01\xa2\x02\x04SASP\xaa\x02%Systemathics.Apis.Services.Private.V1\xca\x02&Systemathics\\Apis\\Services\\Private_\\V1\xe2\x02\x32Systemathics\\Apis\\Services\\Private_\\V1\\GPBMetadata\xea\x02)Systemathics::Apis::Services::Private::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.private.v1.memos_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.systemathics.apis.services.private.v1B\nMemosProtoP\001\242\002\004SASP\252\002%Systemathics.Apis.Services.Private.V1\312\002&Systemathics\\Apis\\Services\\Private_\\V1\342\0022Systemathics\\Apis\\Services\\Private_\\V1\\GPBMetadata\352\002)Systemathics::Apis::Services::Private::V1'
  _globals['_MEMOSSERVICE'].methods_by_name['Memos']._loaded_options = None
  _globals['_MEMOSSERVICE'].methods_by_name['Memos']._serialized_options = b'\202\323\344\223\002\013\022\t/v1/memos'
  _globals['_MEMOSSEARCHTYPE']._serialized_start=551
  _globals['_MEMOSSEARCHTYPE']._serialized_end=679
  _globals['_MEMOSREQUEST']._serialized_start=200
  _globals['_MEMOSREQUEST']._serialized_end=442
  _globals['_MEMOSRESPONSE']._serialized_start=444
  _globals['_MEMOSRESPONSE']._serialized_end=548
  _globals['_MEMOSSERVICE']._serialized_start=682
  _globals['_MEMOSSERVICE']._serialized_end=832
# @@protoc_insertion_point(module_scope)
