# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/tick_analytics/v1/tick_spread.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/tick_analytics/v1/tick_spread.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>systemathics/apis/services/tick_analytics/v1/tick_spread.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xe4\x02\n\x11TickSpreadRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12O\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.ConstraintsR\x0b\x63onstraints\x12?\n\x0cmin_accepted\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x0bminAccepted\x12?\n\x0cmax_accepted\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x0bmaxAccepted\x12\x16\n\x06\x61\x63\x63\x65pt\x18\x05 \x03(\tR\x06\x61\x63\x63\x65pt\x12\x16\n\x06reject\x18\x06 \x03(\tR\x06reject\"\xaa\x02\n\x12TickSpreadResponse\x12H\n\x03\x62id\x18\x01 \x01(\x0b\x32\x36.systemathics.apis.services.tick_analytics.v1.SideDataR\x03\x62id\x12H\n\x03\x61sk\x18\x02 \x01(\x0b\x32\x36.systemathics.apis.services.tick_analytics.v1.SideDataR\x03\x61sk\x12\x12\n\x04last\x18\x03 \x01(\x01R\x04last\x12\x18\n\x07\x61verage\x18\x04 \x01(\x01R\x07\x61verage\x12\x10\n\x03min\x18\x05 \x01(\x01R\x03min\x12\x10\n\x03max\x18\x06 \x01(\x01R\x03max\x12\x14\n\x05\x63ount\x18\x07 \x01(\x03R\x05\x63ount\x12\x18\n\x07skipped\x18\x08 \x01(\x03R\x07skipped\"\x9e\x01\n\x08SideData\x12\x12\n\x04last\x18\x01 \x01(\x01R\x04last\x12\x18\n\x07\x61verage\x18\x02 \x01(\x01R\x07\x61verage\x12\x12\n\x04vwap\x18\x03 \x01(\x01R\x04vwap\x12\x10\n\x03min\x18\x04 \x01(\x01R\x03min\x12\x10\n\x03max\x18\x05 \x01(\x01R\x03max\x12\x16\n\x06volume\x18\x06 \x01(\x03R\x06volume\x12\x14\n\x05\x63ount\x18\x07 \x01(\x03R\x05\x63ount2\xca\x01\n\x11TickSpreadService\x12\xb4\x01\n\nTickSpread\x12?.systemathics.apis.services.tick_analytics.v1.TickSpreadRequest\x1a@.systemathics.apis.services.tick_analytics.v1.TickSpreadResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/tick-analytics/spread0\x01\x42\x94\x02\n0com.systemathics.apis.services.tick_analytics.v1B\x0fTickSpreadProtoP\x01\xa2\x02\x04SAST\xaa\x02+Systemathics.Apis.Services.TickAnalytics.V1\xca\x02+Systemathics\\Apis\\Services\\TickAnalytics\\V1\xe2\x02\x37Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\xea\x02/Systemathics::Apis::Services::TickAnalytics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick_analytics.v1.tick_spread_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.systemathics.apis.services.tick_analytics.v1B\017TickSpreadProtoP\001\242\002\004SAST\252\002+Systemathics.Apis.Services.TickAnalytics.V1\312\002+Systemathics\\Apis\\Services\\TickAnalytics\\V1\342\0027Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\352\002/Systemathics::Apis::Services::TickAnalytics::V1'
  _globals['_TICKSPREADSERVICE'].methods_by_name['TickSpread']._loaded_options = None
  _globals['_TICKSPREADSERVICE'].methods_by_name['TickSpread']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/tick-analytics/spread'
  _globals['_TICKSPREADREQUEST']._serialized_start=278
  _globals['_TICKSPREADREQUEST']._serialized_end=634
  _globals['_TICKSPREADRESPONSE']._serialized_start=637
  _globals['_TICKSPREADRESPONSE']._serialized_end=935
  _globals['_SIDEDATA']._serialized_start=938
  _globals['_SIDEDATA']._serialized_end=1096
  _globals['_TICKSPREADSERVICE']._serialized_start=1099
  _globals['_TICKSPREADSERVICE']._serialized_end=1301
# @@protoc_insertion_point(module_scope)
