# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/tick_analytics/v2/tick_vwap_hp.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/tick_analytics/v2/tick_vwap_hp.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v2 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_constraints__pb2
from systemathics.apis.type.shared.v2 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_identifier__pb2
from systemathics.apis.type.shared.v2 import decimals_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_decimals__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?systemathics/apis/services/tick_analytics/v2/tick_vwap_hp.proto\x12,systemathics.apis.services.tick_analytics.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x32systemathics/apis/type/shared/v2/constraints.proto\x1a\x31systemathics/apis/type/shared/v2/identifier.proto\x1a/systemathics/apis/type/shared/v2/decimals.proto\"\xb9\x03\n\x11HpTickVwapRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v2.IdentifierR\nidentifier\x12O\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v2.ConstraintsR\x0b\x63onstraints\x12\x31\n\x06period\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06period\x12\x31\n\x06offset\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06offset\x12\x1e\n\nadjustment\x18\x05 \x01(\x08R\nadjustment\x12\x16\n\x06\x61\x63\x63\x65pt\x18\x06 \x03(\tR\x06\x61\x63\x63\x65pt\x12\x16\n\x06reject\x18\x07 \x03(\tR\x06reject\x12O\n\x15\x62uffering_window_size\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x13\x62ufferingWindowSize\"\x90\x03\n\x12HpTickVwapResponse\x12\x39\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x43\n\x04vwap\x18\x02 \x01(\x0b\x32/.systemathics.apis.type.shared.v2.SignedDecimalR\x04vwap\x12\x45\n\x05trade\x18\x03 \x01(\x0b\x32/.systemathics.apis.type.shared.v2.SignedDecimalR\x05trade\x12I\n\x06volume\x18\x04 \x01(\x0b\x32\x31.systemathics.apis.type.shared.v2.UnsignedDecimalR\x06volume\x12\x14\n\x05\x63ount\x18\x05 \x01(\x04R\x05\x63ount\x12R\n\x16total_processed_frames\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueR\x14totalProcessedFrames2\xcb\x01\n\x11HpTickVwapService\x12\xb5\x01\n\nHpTickVwap\x12?.systemathics.apis.services.tick_analytics.v2.HpTickVwapRequest\x1a@.systemathics.apis.services.tick_analytics.v2.HpTickVwapResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v2/tick-analytics/vwap-hp0\x01\x42\x94\x02\n0com.systemathics.apis.services.tick_analytics.v2B\x0fTickVwapHpProtoP\x01\xa2\x02\x04SAST\xaa\x02+Systemathics.Apis.Services.TickAnalytics.V2\xca\x02+Systemathics\\Apis\\Services\\TickAnalytics\\V2\xe2\x02\x37Systemathics\\Apis\\Services\\TickAnalytics\\V2\\GPBMetadata\xea\x02/Systemathics::Apis::Services::TickAnalytics::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick_analytics.v2.tick_vwap_hp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.systemathics.apis.services.tick_analytics.v2B\017TickVwapHpProtoP\001\242\002\004SAST\252\002+Systemathics.Apis.Services.TickAnalytics.V2\312\002+Systemathics\\Apis\\Services\\TickAnalytics\\V2\342\0027Systemathics\\Apis\\Services\\TickAnalytics\\V2\\GPBMetadata\352\002/Systemathics::Apis::Services::TickAnalytics::V2'
  _globals['_HPTICKVWAPSERVICE'].methods_by_name['HpTickVwap']._loaded_options = None
  _globals['_HPTICKVWAPSERVICE'].methods_by_name['HpTickVwap']._serialized_options = b'\202\323\344\223\002\034\022\032/v2/tick-analytics/vwap-hp'
  _globals['_HPTICKVWAPREQUEST']._serialized_start=393
  _globals['_HPTICKVWAPREQUEST']._serialized_end=834
  _globals['_HPTICKVWAPRESPONSE']._serialized_start=837
  _globals['_HPTICKVWAPRESPONSE']._serialized_end=1237
  _globals['_HPTICKVWAPSERVICE']._serialized_start=1240
  _globals['_HPTICKVWAPSERVICE']._serialized_end=1443
# @@protoc_insertion_point(module_scope)
