# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/v2/artifacts.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/v2/artifacts.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-systemathics/apis/services/v2/artifacts.proto\x12\x1dsystemathics.apis.services.v2\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf2\x01\n\x10\x41rtifactsRequest\x12#\n\rsearch_string\x18\x01 \x01(\tR\x0csearchString\x12S\n\x0bsearch_type\x18\x02 \x01(\x0e\x32\x32.systemathics.apis.services.v2.ArtifactsSearchTypeR\nsearchType\x12\x31\n\x05start\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05start\x12\x31\n\x05\x63ount\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05\x63ount\"u\n\x11\x41rtifactsResponse\x12\x45\n\tartifacts\x18\x01 \x03(\x0b\x32\'.systemathics.apis.services.v2.ArtifactR\tartifacts\x12\x19\n\x08has_more\x18\x02 \x01(\x08R\x07hasMore\"\xc3\x03\n\x08\x41rtifact\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04size\x18\x02 \x01(\x03R\x04size\x12?\n\rlast_modified\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0clastModified\x12\x32\n\x05xxh64\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05xxh64\x12K\n\x13normalization_start\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x12normalizationStart\x12G\n\x11normalization_end\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10normalizationEnd\x12\x43\n\x0fpromotion_start\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0epromotionStart\x12?\n\rpromotion_end\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0cpromotionEnd*\x90\x01\n\x13\x41rtifactsSearchType\x12%\n!ARTIFACTS_SEARCH_TYPE_UNSPECIFIED\x10\x00\x12$\n ARTIFACTS_SEARCH_TYPE_SUB_STRING\x10\x01\x12,\n(ARTIFACTS_SEARCH_TYPE_REGULAR_EXPRESSION\x10\x02\x32\x82\x01\n\x10\x41rtifactsService\x12n\n\tArtifacts\x12/.systemathics.apis.services.v2.ArtifactsRequest\x1a\x30.systemathics.apis.services.v2.ArtifactsResponseB\xca\x01\n!com.systemathics.apis.services.v2B\x0e\x41rtifactsProtoP\x01\xa2\x02\x03SAS\xaa\x02\x1dSystemathics.Apis.Services.V2\xca\x02\x1dSystemathics\\Apis\\Services\\V2\xe2\x02)Systemathics\\Apis\\Services\\V2\\GPBMetadata\xea\x02 Systemathics::Apis::Services::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.v2.artifacts_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.systemathics.apis.services.v2B\016ArtifactsProtoP\001\242\002\003SAS\252\002\035Systemathics.Apis.Services.V2\312\002\035Systemathics\\Apis\\Services\\V2\342\002)Systemathics\\Apis\\Services\\V2\\GPBMetadata\352\002 Systemathics::Apis::Services::V2'
  _globals['_ARTIFACTSSEARCHTYPE']._serialized_start=964
  _globals['_ARTIFACTSSEARCHTYPE']._serialized_end=1108
  _globals['_ARTIFACTSREQUEST']._serialized_start=146
  _globals['_ARTIFACTSREQUEST']._serialized_end=388
  _globals['_ARTIFACTSRESPONSE']._serialized_start=390
  _globals['_ARTIFACTSRESPONSE']._serialized_end=507
  _globals['_ARTIFACT']._serialized_start=510
  _globals['_ARTIFACT']._serialized_end=961
  _globals['_ARTIFACTSSERVICE']._serialized_start=1111
  _globals['_ARTIFACTSSERVICE']._serialized_end=1241
# @@protoc_insertion_point(module_scope)
