# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/topology/v2/topologies.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/topology/v2/topologies.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v2 import memo_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_memo__pb2
from systemathics.apis.type.shared.v2 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_level__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7systemathics/apis/services/topology/v2/topologies.proto\x12&systemathics.apis.services.topology.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a+systemathics/apis/type/shared/v2/memo.proto\x1a,systemathics/apis/type/shared/v2/level.proto\"\x94\x02\n\x11TopologiesRequest\x12:\n\x04memo\x18\x01 \x01(\x0b\x32&.systemathics.apis.type.shared.v2.MemoR\x04memo\x12]\n\x0bgranularity\x18\x02 \x01(\x0e\x32;.systemathics.apis.services.topology.v2.TopologyGranularityR\x0bgranularity\x12\x31\n\x05start\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05start\x12\x31\n\x05\x63ount\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05\x63ount\"~\n\rTopologyEntry\x12\'\n\x05\x62\x65gin\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x05\x62\x65gin\x12#\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x03\x65nd\x12\x1f\n\x0bticks_count\x18\x03 \x01(\x04R\nticksCount\"\x80\x01\n\x12TopologiesResponse\x12O\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x35.systemathics.apis.services.topology.v2.TopologyEntryR\x07\x65ntries\x12\x19\n\x08has_more\x18\x02 \x01(\x08R\x07hasMore*\xe2\x01\n\x13TopologyGranularity\x12$\n TOPOLOGY_GRANULARITY_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTOPOLOGY_GRANULARITY_DAILY\x10\x01\x12\x1f\n\x1bTOPOLOGY_GRANULARITY_WEEKLY\x10\x02\x12 \n\x1cTOPOLOGY_GRANULARITY_MONTHLY\x10\x03\x12!\n\x1dTOPOLOGY_GRANULARITY_QUATERLY\x10\x04\x12\x1f\n\x1bTOPOLOGY_GRANULARITY_YEARLY\x10\x05\x32\xb1\x01\n\x11TopologiesService\x12\x9b\x01\n\nTopologies\x12\x39.systemathics.apis.services.topology.v2.TopologiesRequest\x1a:.systemathics.apis.services.topology.v2.TopologiesResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v2/topologiesB\xfa\x01\n*com.systemathics.apis.services.topology.v2B\x0fTopologiesProtoP\x01\xa2\x02\x04SAST\xaa\x02&Systemathics.Apis.Services.Topology.V2\xca\x02&Systemathics\\Apis\\Services\\Topology\\V2\xe2\x02\x32Systemathics\\Apis\\Services\\Topology\\V2\\GPBMetadata\xea\x02*Systemathics::Apis::Services::Topology::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.topology.v2.topologies_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.systemathics.apis.services.topology.v2B\017TopologiesProtoP\001\242\002\004SAST\252\002&Systemathics.Apis.Services.Topology.V2\312\002&Systemathics\\Apis\\Services\\Topology\\V2\342\0022Systemathics\\Apis\\Services\\Topology\\V2\\GPBMetadata\352\002*Systemathics::Apis::Services::Topology::V2'
  _globals['_TOPOLOGIESSERVICE'].methods_by_name['Topologies']._loaded_options = None
  _globals['_TOPOLOGIESSERVICE'].methods_by_name['Topologies']._serialized_options = b'\202\323\344\223\002\020\022\016/v2/topologies'
  _globals['_TOPOLOGYGRANULARITY']._serialized_start=815
  _globals['_TOPOLOGYGRANULARITY']._serialized_end=1041
  _globals['_TOPOLOGIESREQUEST']._serialized_start=277
  _globals['_TOPOLOGIESREQUEST']._serialized_end=553
  _globals['_TOPOLOGYENTRY']._serialized_start=555
  _globals['_TOPOLOGYENTRY']._serialized_end=681
  _globals['_TOPOLOGIESRESPONSE']._serialized_start=684
  _globals['_TOPOLOGIESRESPONSE']._serialized_end=812
  _globals['_TOPOLOGIESSERVICE']._serialized_start=1044
  _globals['_TOPOLOGIESSERVICE']._serialized_end=1221
# @@protoc_insertion_point(module_scope)
