# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/tick/v2/tick_raw.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/tick/v2/tick_raw.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v2 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_constraints__pb2
from systemathics.apis.type.shared.v2 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_identifier__pb2
from systemathics.apis.type.shared.v2 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_level__pb2
from systemathics.apis.type.shared.v2 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_keys__pb2
from systemathics.apis.type.shared.v2 import raw_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_raw__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1systemathics/apis/services/tick/v2/tick_raw.proto\x12\"systemathics.apis.services.tick.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x32systemathics/apis/type/shared/v2/constraints.proto\x1a\x31systemathics/apis/type/shared/v2/identifier.proto\x1a,systemathics/apis/type/shared/v2/level.proto\x1a+systemathics/apis/type/shared/v2/keys.proto\x1a*systemathics/apis/type/shared/v2/raw.proto\"\xc1\x02\n\x0eTickRawRequest\x12N\n\x0bidentifiers\x18\x01 \x03(\x0b\x32,.systemathics.apis.type.shared.v2.IdentifierR\x0bidentifiers\x12=\n\x05level\x18\x02 \x01(\x0e\x32\'.systemathics.apis.type.shared.v2.LevelR\x05level\x12O\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v2.ConstraintsR\x0b\x63onstraints\x12O\n\x15\x62uffering_window_size\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x13\x62ufferingWindowSize\"\x9b\x01\n\x0fTickRawResponse\x12\x39\n\x03raw\x18\x01 \x01(\x0b\x32%.systemathics.apis.type.shared.v2.RawH\x00R\x03raw\x12\x42\n\x07mapping\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v2.KeysH\x00R\x07mappingB\t\n\x07payload2\x9d\x01\n\x0eTickRawService\x12\x8a\x01\n\x07TickRaw\x12\x32.systemathics.apis.services.tick.v2.TickRawRequest\x1a\x33.systemathics.apis.services.tick.v2.TickRawResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v2/tick/raw0\x01\x42\xe3\x01\n&com.systemathics.apis.services.tick.v2B\x0cTickRawProtoP\x01\xa2\x02\x04SAST\xaa\x02\"Systemathics.Apis.Services.Tick.V2\xca\x02\"Systemathics\\Apis\\Services\\Tick\\V2\xe2\x02.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\xea\x02&Systemathics::Apis::Services::Tick::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick.v2.tick_raw_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.systemathics.apis.services.tick.v2B\014TickRawProtoP\001\242\002\004SAST\252\002\"Systemathics.Apis.Services.Tick.V2\312\002\"Systemathics\\Apis\\Services\\Tick\\V2\342\002.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\352\002&Systemathics::Apis::Services::Tick::V2'
  _globals['_TICKRAWSERVICE'].methods_by_name['TickRaw']._loaded_options = None
  _globals['_TICKRAWSERVICE'].methods_by_name['TickRaw']._serialized_options = b'\202\323\344\223\002\016\022\014/v2/tick/raw'
  _globals['_TICKRAWREQUEST']._serialized_start=390
  _globals['_TICKRAWREQUEST']._serialized_end=711
  _globals['_TICKRAWRESPONSE']._serialized_start=714
  _globals['_TICKRAWRESPONSE']._serialized_end=869
  _globals['_TICKRAWSERVICE']._serialized_start=872
  _globals['_TICKRAWSERVICE']._serialized_end=1029
# @@protoc_insertion_point(module_scope)
