# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/daily/v1/daily_implied_volatility.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/daily/v1/daily_implied_volatility.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBsystemathics/apis/services/daily/v1/daily_implied_volatility.proto\x12#systemathics.apis.services.daily.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\xc4\x01\n\x1f\x44\x61ilyImpliedVolatilitiesRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12S\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\"s\n DailyImpliedVolatilitiesResponse\x12O\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32;.systemathics.apis.services.daily.v1.DailyImpliedVolatilityR\x04\x64\x61ta\"k\n\x16\x44\x61ilyImpliedVolatility\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value\x12\x14\n\x05score\x18\x03 \x01(\x01R\x05score2\xf2\x01\n\x1f\x44\x61ilyImpliedVolatilitiesService\x12\xce\x01\n\x18\x44\x61ilyImpliedVolatilities\x12\x44.systemathics.apis.services.daily.v1.DailyImpliedVolatilitiesRequest\x1a\x45.systemathics.apis.services.daily.v1.DailyImpliedVolatilitiesResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/daily/impliedvolatilitiesB\xf7\x01\n\'com.systemathics.apis.services.daily.v1B\x1b\x44\x61ilyImpliedVolatilityProtoP\x01\xa2\x02\x04SASD\xaa\x02#Systemathics.Apis.Services.Daily.V1\xca\x02#Systemathics\\Apis\\Services\\Daily\\V1\xe2\x02/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\xea\x02\'Systemathics::Apis::Services::Daily::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily.v1.daily_implied_volatility_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.systemathics.apis.services.daily.v1B\033DailyImpliedVolatilityProtoP\001\242\002\004SASD\252\002#Systemathics.Apis.Services.Daily.V1\312\002#Systemathics\\Apis\\Services\\Daily\\V1\342\002/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\352\002\'Systemathics::Apis::Services::Daily::V1'
  _globals['_DAILYIMPLIEDVOLATILITIESSERVICE'].methods_by_name['DailyImpliedVolatilities']._loaded_options = None
  _globals['_DAILYIMPLIEDVOLATILITIESSERVICE'].methods_by_name['DailyImpliedVolatilities']._serialized_options = b'\202\323\344\223\002\037\022\035/v1/daily/impliedvolatilities'
  _globals['_DAILYIMPLIEDVOLATILITIESREQUEST']._serialized_start=267
  _globals['_DAILYIMPLIEDVOLATILITIESREQUEST']._serialized_end=463
  _globals['_DAILYIMPLIEDVOLATILITIESRESPONSE']._serialized_start=465
  _globals['_DAILYIMPLIEDVOLATILITIESRESPONSE']._serialized_end=580
  _globals['_DAILYIMPLIEDVOLATILITY']._serialized_start=582
  _globals['_DAILYIMPLIEDVOLATILITY']._serialized_end=689
  _globals['_DAILYIMPLIEDVOLATILITIESSERVICE']._serialized_start=692
  _globals['_DAILYIMPLIEDVOLATILITIESSERVICE']._serialized_end=934
# @@protoc_insertion_point(module_scope)
