# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/static_data/v1/static_data.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/static_data/v1/static_data.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;systemathics/apis/services/static_data/v1/static_data.proto\x12)systemathics.apis.services.static_data.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xc4\x11\n\x11StaticDataRequest\x12S\n\nasset_type\x18\x01 \x01(\x0e\x32\x34.systemathics.apis.services.static_data.v1.AssetTypeR\tassetType\x12\x31\n\x05start\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05start\x12\x31\n\x05\x63ount\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05\x63ount\x12:\n\tbloomberg\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tbloomberg\x12.\n\x03\x63ik\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x03\x63ik\x12<\n\ncomponents\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\ncomponents\x12\x38\n\x08\x63ontract\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x63ontract\x12\x41\n\rbase_currency\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0c\x62\x61seCurrency\x12\x43\n\x0equote_currency\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rquoteCurrency\x12\x32\n\x05\x63usip\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05\x63usip\x12>\n\x0b\x64\x65scription\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0b\x64\x65scription\x12\x38\n\x08\x65xchange\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x65xchange\x12\x30\n\x04\x66igi\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04\x66igi\x12\x32\n\x05\x66igic\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05\x66igic\x12\x32\n\x05index\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05index\x12\x30\n\x04isin\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04isin\x12\x34\n\x06markit\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06markit\x12>\n\x0bmorningstar\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0bmorningstar\x12\x30\n\x04name\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04name\x12:\n\toperating\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\toperating\x12\x36\n\x07primary\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07primary\x12\x36\n\x07reuters\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07reuters\x12\x34\n\x06sector\x18\x17 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06sector\x12\x32\n\x05sedol\x18\x18 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05sedol\x12\x34\n\x06ticker\x18\x19 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06ticker\x12<\n\nunderlying\x18\x1a \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nunderlying\x12\x44\n\x0e\x63lassification\x18\x1b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0e\x63lassification\x12Z\n\x08maturity\x18\x1c \x01(\x0b\x32>.systemathics.apis.services.static_data.v1.StaticDataDateRangeR\x08maturity\x12h\n\x0e\x63\x61pitalization\x18\x1d \x01(\x0b\x32@.systemathics.apis.services.static_data.v1.StaticDataDoubleRangeR\x0e\x63\x61pitalization\x12V\n\x06\x65xpiry\x18\x1e \x01(\x0b\x32>.systemathics.apis.services.static_data.v1.StaticDataDateRangeR\x06\x65xpiry\x12V\n\x0boption_type\x18\x1f \x01(\x0e\x32\x35.systemathics.apis.services.static_data.v1.OptionTypeR\noptionType\x12\\\n\rexercise_type\x18  \x01(\x0e\x32\x37.systemathics.apis.services.static_data.v1.ExerciseTypeR\x0c\x65xerciseType\x12P\n\tbond_type\x18! \x01(\x0e\x32\x33.systemathics.apis.services.static_data.v1.BondTypeR\x08\x62ondType\x12:\n\tseniority\x18\" \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tseniority\x12\x34\n\x06issuer\x18# \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06issuer\"\x8b\x01\n\x13StaticDataDateRange\x12.\n\tless_than\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x08lessThan\x12\x44\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x12greaterOrEqualThan\"\xa3\x01\n\x15StaticDataDoubleRange\x12\x39\n\tless_than\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x08lessThan\x12O\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x12greaterOrEqualThan\"\xe1\x05\n\x12StaticDataResponse\x12Q\n\x06\x66uture\x18\x01 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.FutureResponseR\x06\x66uture\x12Q\n\x06\x65quity\x18\x02 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.EquityResponseR\x06\x65quity\x12H\n\x03\x65tf\x18\x03 \x01(\x0b\x32\x36.systemathics.apis.services.static_data.v1.EtfResponseR\x03\x65tf\x12N\n\x05index\x18\x04 \x01(\x0b\x32\x38.systemathics.apis.services.static_data.v1.IndexResponseR\x05index\x12Q\n\x06\x63rypto\x18\x05 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.CryptoResponseR\x06\x63rypto\x12N\n\x05\x66orex\x18\x06 \x01(\x0b\x32\x38.systemathics.apis.services.static_data.v1.ForexResponseR\x05\x66orex\x12Q\n\x06option\x18\x07 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.OptionResponseR\x06option\x12K\n\x04\x62ond\x18\x08 \x01(\x0b\x32\x37.systemathics.apis.services.static_data.v1.BondResponseR\x04\x62ond\x12H\n\x03\x63\x64s\x18\t \x01(\x0b\x32\x36.systemathics.apis.services.static_data.v1.CdsResponseR\x03\x63\x64s\"}\n\x0c\x42ondResponse\x12L\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x34.systemathics.apis.services.static_data.v1.BondEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"{\n\x0b\x43\x64sResponse\x12K\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.CdsEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x81\x01\n\x0e\x43ryptoResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.CryptoEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x81\x01\n\x0e\x45quityResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.EquityEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"{\n\x0b\x45tfResponse\x12K\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.EtfEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x7f\n\rForexResponse\x12M\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x35.systemathics.apis.services.static_data.v1.ForexEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x81\x01\n\x0e\x46utureResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.FutureEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x7f\n\rIndexResponse\x12M\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x35.systemathics.apis.services.static_data.v1.IndexEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x81\x01\n\x0eOptionResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.OptionEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\xa0\r\n\x0b\x45quityEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12]\n\x07mapping\x18\x16 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x10\n\x03\x63ik\x18! \x01(\tR\x03\x63ik\x12]\n\x07sectors\x18\" \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntryR\x07sectors\x12\x44\n\x0e\x63\x61pitalization\x18# \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x0e\x63\x61pitalization\x12\x18\n\x07\x61\x64\x64ress\x18$ \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05phone\x18% \x01(\tR\x05phone\x12\x14\n\x05\x65mail\x18& \x01(\tR\x05\x65mail\x12\x10\n\x03url\x18\' \x01(\tR\x03url\x12]\n\x07holders\x18( \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.HoldersEntryR\x07holders\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a:\n\x0cSectorsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a:\n\x0cHoldersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xe3\x0c\n\x08\x45tfEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12Z\n\x07mapping\x18\x16 \x03(\x0b\x32@.systemathics.apis.services.static_data.v1.EtfEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x10\n\x03\x63ik\x18! \x01(\tR\x03\x63ik\x12Z\n\x07sectors\x18\" \x03(\x0b\x32@.systemathics.apis.services.static_data.v1.EtfEntry.SectorsEntryR\x07sectors\x12\x44\n\x0e\x63\x61pitalization\x18# \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x0e\x63\x61pitalization\x12\x18\n\x07\x61\x64\x64ress\x18$ \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05phone\x18% \x01(\tR\x05phone\x12\x14\n\x05\x65mail\x18& \x01(\tR\x05\x65mail\x12\x10\n\x03url\x18\' \x01(\tR\x03url\x12\x16\n\x06issuer\x18( \x01(\tR\x06issuer\x12\x1b\n\tfund_type\x18) \x01(\tR\x08\x66undType\x12\x30\n\nissue_date\x18* \x01(\x0b\x32\x11.google.type.DateR\tissueDate\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a:\n\x0cSectorsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x84\x0c\n\x0b\x46utureEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12]\n\x07mapping\x18\x16 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.FutureEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x1e\n\nunderlying\x18! \x01(\tR\nunderlying\x12\x1a\n\x08\x63ontract\x18\" \x01(\tR\x08\x63ontract\x12`\n\x08\x63\x61tegory\x18# \x03(\x0b\x32\x44.systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntryR\x08\x63\x61tegory\x12\x14\n\x05\x63hain\x18$ \x01(\tR\x05\x63hain\x12-\n\x08maturity\x18% \x01(\x0b\x32\x11.google.type.DateR\x08maturity\x12\x14\n\x05month\x18& \x01(\tR\x05month\x12\x12\n\x04year\x18\' \x01(\x05R\x04year\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a;\n\rCategoryEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xe9\x0c\n\nIndexEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12\\\n\x07mapping\x18\x16 \x03(\x0b\x32\x42.systemathics.apis.services.static_data.v1.IndexEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x1a\n\x08\x63\x61tegory\x18! \x01(\tR\x08\x63\x61tegory\x12 \n\x0bmethodology\x18\" \x01(\tR\x0bmethodology\x12\x16\n\x06issuer\x18# \x01(\tR\x06issuer\x12\x30\n\nissue_date\x18$ \x01(\x0b\x32\x11.google.type.DateR\tissueDate\x12V\n\tfrequency\x18% \x01(\x0e\x32\x38.systemathics.apis.services.static_data.v1.FrequencyTypeR\tfrequency\x12\x65\n\ncomponents\x18& \x03(\x0b\x32\x45.systemathics.apis.services.static_data.v1.IndexEntry.ComponentsEntryR\ncomponents\x12)\n\x10\x63omponents_count\x18\' \x01(\x03R\x0f\x63omponentsCount\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a=\n\x0f\x43omponentsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xf1\x0b\n\x0b\x43ryptoEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12#\n\rbase_currency\x18\x07 \x01(\tR\x0c\x62\x61seCurrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12]\n\x07mapping\x18\x16 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.CryptoEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12%\n\x0equote_currency\x18! \x01(\tR\rquoteCurrency\x12\x1c\n\tconsensus\x18\" \x03(\tR\tconsensus\x12\x30\n\nissue_date\x18# \x01(\x0b\x32\x11.google.type.DateR\tissueDate\x12\x44\n\x0e\x63\x61pitalization\x18$ \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x0e\x63\x61pitalization\x12-\n\x12\x63irculating_supply\x18% \x01(\x05R\x11\x63irculatingSupply\x12\x1d\n\nmax_supply\x18& \x01(\x05R\tmaxSupply\x12!\n\x0ctotal_supply\x18\' \x01(\x05R\x0btotalSupply\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xe8\t\n\nForexEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12#\n\rbase_currency\x18\x07 \x01(\tR\x0c\x62\x61seCurrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12\\\n\x07mapping\x18\x16 \x03(\x0b\x32\x42.systemathics.apis.services.static_data.v1.ForexEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12%\n\x0equote_currency\x18! \x01(\tR\rquoteCurrency\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xd3\x0b\n\x0bOptionEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12]\n\x07mapping\x18\x16 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.OptionEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x1e\n\nunderlying\x18! \x01(\tR\nunderlying\x12\x16\n\x06strike\x18\" \x01(\x01R\x06strike\x12)\n\x06\x65xpiry\x18# \x01(\x0b\x32\x11.google.type.DateR\x06\x65xpiry\x12V\n\x0boption_type\x18$ \x01(\x0e\x32\x35.systemathics.apis.services.static_data.v1.OptionTypeR\noptionType\x12\\\n\rexercise_type\x18% \x01(\x0e\x32\x37.systemathics.apis.services.static_data.v1.ExerciseTypeR\x0c\x65xerciseType\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xec\r\n\tBondEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12[\n\x07mapping\x18\x16 \x03(\x0b\x32\x41.systemathics.apis.services.static_data.v1.BondEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x16\n\x06issuer\x18! \x01(\tR\x06issuer\x12-\n\x08maturity\x18\" \x01(\x0b\x32\x11.google.type.DateR\x08maturity\x12P\n\tbond_type\x18# \x01(\x0e\x32\x33.systemathics.apis.services.static_data.v1.BondTypeR\x08\x62ondType\x12V\n\tfrequency\x18$ \x01(\x0e\x32\x38.systemathics.apis.services.static_data.v1.FrequencyTypeR\tfrequency\x12V\n\x0b\x63oupon_type\x18% \x01(\x0e\x32\x35.systemathics.apis.services.static_data.v1.CouponTypeR\ncouponType\x12\x1f\n\x0b\x63oupon_rate\x18& \x01(\x01R\ncouponRate\x12\x30\n\nissue_date\x18\' \x01(\x0b\x32\x11.google.type.DateR\tissueDate\x12\"\n\x0c\x64\x65nomination\x18( \x01(\x01R\x0c\x64\x65nomination\x12\x1f\n\x0bissue_price\x18) \x01(\x01R\nissuePrice\x12\x14\n\x05total\x18* \x01(\x01R\x05total\x12\x1f\n\x0b\x66\x61\x63\x65_amount\x18+ \x01(\x01R\nfaceAmount\x12\x1c\n\tseniority\x18, \x01(\tR\tseniority\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x8d\x0b\n\x08\x43\x64sEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12Z\n\x07mapping\x18\x16 \x03(\x0b\x32@.systemathics.apis.services.static_data.v1.CdsEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x1e\n\nunderlying\x18! \x01(\tR\nunderlying\x12-\n\x08maturity\x18\" \x01(\x0b\x32\x11.google.type.DateR\x08maturity\x12V\n\tfrequency\x18# \x01(\x0e\x32\x38.systemathics.apis.services.static_data.v1.FrequencyTypeR\tfrequency\x12\x14\n\x05tenor\x18$ \x01(\tR\x05tenor\x12\x1a\n\x08recovery\x18% \x01(\x01R\x08recovery\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"4\n\x08TickSize\x12\x14\n\x05price\x18\x01 \x01(\x01R\x05price\x12\x12\n\x04tick\x18\x02 \x01(\x01R\x04tick*\x80\x02\n\tAssetType\x12\x1a\n\x16\x41SSET_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41SSET_TYPE_ALL\x10\x01\x12\x15\n\x11\x41SSET_TYPE_EQUITY\x10\x02\x12\x15\n\x11\x41SSET_TYPE_FUTURE\x10\x03\x12\x12\n\x0e\x41SSET_TYPE_ETF\x10\x04\x12\x14\n\x10\x41SSET_TYPE_INDEX\x10\x05\x12\x15\n\x11\x41SSET_TYPE_CRYPTO\x10\x06\x12\x14\n\x10\x41SSET_TYPE_FOREX\x10\x07\x12\x15\n\x11\x41SSET_TYPE_OPTION\x10\x08\x12\x13\n\x0f\x41SSET_TYPE_BOND\x10\t\x12\x12\n\x0e\x41SSET_TYPE_CDS\x10\n*\x86\x02\n\rFrequencyType\x12\x1e\n\x1a\x46REQUENCY_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13\x46REQUENCY_TYPE_NONE\x10\x01\x12\x16\n\x12\x46REQUENCY_TYPE_DAY\x10\x02\x12\x17\n\x13\x46REQUENCY_TYPE_WEEK\x10\x03\x12\x18\n\x14\x46REQUENCY_TYPE_MONTH\x10\x04\x12\x1a\n\x16\x46REQUENCY_TYPE_QUARTER\x10\x05\x12\x1d\n\x19\x46REQUENCY_TYPE_SEMIANNUAL\x10\x06\x12\x19\n\x15\x46REQUENCY_TYPE_ANNUAL\x10\x07\x12\x1b\n\x17\x46REQUENCY_TYPE_BIANNUAL\x10\x08*T\n\nOptionType\x12\x1b\n\x17OPTION_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10OPTION_TYPE_CALL\x10\x01\x12\x13\n\x0fOPTION_TYPE_PUT\x10\x02*\x81\x01\n\x0c\x45xerciseType\x12\x1d\n\x19\x45XERCISE_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x45XERCISE_TYPE_AMERICAN\x10\x01\x12\x1a\n\x16\x45XERCISE_TYPE_EUROPEAN\x10\x02\x12\x1a\n\x16\x45XERCISE_TYPE_BERMUDAN\x10\x03*m\n\x08\x42ondType\x12\x19\n\x15\x42OND_TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x42OND_TYPE_GOVERNMENT\x10\x01\x12\x17\n\x13\x42OND_TYPE_CORPORATE\x10\x02\x12\x13\n\x0f\x42OND_TYPE_OTHER\x10\x03*p\n\nCouponType\x12\x1b\n\x17\x43OUPON_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43OUPON_TYPE_NONE\x10\x01\x12\x15\n\x11\x43OUPON_TYPE_FIXED\x10\x02\x12\x18\n\x14\x43OUPON_TYPE_FLOATING\x10\x03\x32\xb7\x01\n\x11StaticDataService\x12\xa1\x01\n\nStaticData\x12<.systemathics.apis.services.static_data.v1.StaticDataRequest\x1a=.systemathics.apis.services.static_data.v1.StaticDataResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/staticdataB\x85\x02\n-com.systemathics.apis.services.static_data.v1B\x0fStaticDataProtoP\x01\xa2\x02\x04SASS\xaa\x02(Systemathics.Apis.Services.StaticData.V1\xca\x02(Systemathics\\Apis\\Services\\StaticData\\V1\xe2\x02\x34Systemathics\\Apis\\Services\\StaticData\\V1\\GPBMetadata\xea\x02,Systemathics::Apis::Services::StaticData::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.static_data.v1.static_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-com.systemathics.apis.services.static_data.v1B\017StaticDataProtoP\001\242\002\004SASS\252\002(Systemathics.Apis.Services.StaticData.V1\312\002(Systemathics\\Apis\\Services\\StaticData\\V1\342\0024Systemathics\\Apis\\Services\\StaticData\\V1\\GPBMetadata\352\002,Systemathics::Apis::Services::StaticData::V1'
  _globals['_EQUITYENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_EQUITYENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_EQUITYENTRY_SECTORSENTRY']._loaded_options = None
  _globals['_EQUITYENTRY_SECTORSENTRY']._serialized_options = b'8\001'
  _globals['_EQUITYENTRY_HOLDERSENTRY']._loaded_options = None
  _globals['_EQUITYENTRY_HOLDERSENTRY']._serialized_options = b'8\001'
  _globals['_ETFENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_ETFENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_ETFENTRY_SECTORSENTRY']._loaded_options = None
  _globals['_ETFENTRY_SECTORSENTRY']._serialized_options = b'8\001'
  _globals['_FUTUREENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_FUTUREENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_FUTUREENTRY_CATEGORYENTRY']._loaded_options = None
  _globals['_FUTUREENTRY_CATEGORYENTRY']._serialized_options = b'8\001'
  _globals['_INDEXENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_INDEXENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_INDEXENTRY_COMPONENTSENTRY']._loaded_options = None
  _globals['_INDEXENTRY_COMPONENTSENTRY']._serialized_options = b'8\001'
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_FOREXENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_FOREXENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_OPTIONENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_OPTIONENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_BONDENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_BONDENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_CDSENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_CDSENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_STATICDATASERVICE'].methods_by_name['StaticData']._loaded_options = None
  _globals['_STATICDATASERVICE'].methods_by_name['StaticData']._serialized_options = b'\202\323\344\223\002\020\022\016/v1/staticdata'
  _globals['_ASSETTYPE']._serialized_start=18788
  _globals['_ASSETTYPE']._serialized_end=19044
  _globals['_FREQUENCYTYPE']._serialized_start=19047
  _globals['_FREQUENCYTYPE']._serialized_end=19309
  _globals['_OPTIONTYPE']._serialized_start=19311
  _globals['_OPTIONTYPE']._serialized_end=19395
  _globals['_EXERCISETYPE']._serialized_start=19398
  _globals['_EXERCISETYPE']._serialized_end=19527
  _globals['_BONDTYPE']._serialized_start=19529
  _globals['_BONDTYPE']._serialized_end=19638
  _globals['_COUPONTYPE']._serialized_start=19640
  _globals['_COUPONTYPE']._serialized_end=19752
  _globals['_STATICDATAREQUEST']._serialized_start=276
  _globals['_STATICDATAREQUEST']._serialized_end=2520
  _globals['_STATICDATADATERANGE']._serialized_start=2523
  _globals['_STATICDATADATERANGE']._serialized_end=2662
  _globals['_STATICDATADOUBLERANGE']._serialized_start=2665
  _globals['_STATICDATADOUBLERANGE']._serialized_end=2828
  _globals['_STATICDATARESPONSE']._serialized_start=2831
  _globals['_STATICDATARESPONSE']._serialized_end=3568
  _globals['_BONDRESPONSE']._serialized_start=3570
  _globals['_BONDRESPONSE']._serialized_end=3695
  _globals['_CDSRESPONSE']._serialized_start=3697
  _globals['_CDSRESPONSE']._serialized_end=3820
  _globals['_CRYPTORESPONSE']._serialized_start=3823
  _globals['_CRYPTORESPONSE']._serialized_end=3952
  _globals['_EQUITYRESPONSE']._serialized_start=3955
  _globals['_EQUITYRESPONSE']._serialized_end=4084
  _globals['_ETFRESPONSE']._serialized_start=4086
  _globals['_ETFRESPONSE']._serialized_end=4209
  _globals['_FOREXRESPONSE']._serialized_start=4211
  _globals['_FOREXRESPONSE']._serialized_end=4338
  _globals['_FUTURERESPONSE']._serialized_start=4341
  _globals['_FUTURERESPONSE']._serialized_end=4470
  _globals['_INDEXRESPONSE']._serialized_start=4472
  _globals['_INDEXRESPONSE']._serialized_end=4599
  _globals['_OPTIONRESPONSE']._serialized_start=4602
  _globals['_OPTIONRESPONSE']._serialized_end=4731
  _globals['_EQUITYENTRY']._serialized_start=4734
  _globals['_EQUITYENTRY']._serialized_end=6430
  _globals['_EQUITYENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_EQUITYENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_EQUITYENTRY_SECTORSENTRY']._serialized_start=6312
  _globals['_EQUITYENTRY_SECTORSENTRY']._serialized_end=6370
  _globals['_EQUITYENTRY_HOLDERSENTRY']._serialized_start=6372
  _globals['_EQUITYENTRY_HOLDERSENTRY']._serialized_end=6430
  _globals['_ETFENTRY']._serialized_start=6433
  _globals['_ETFENTRY']._serialized_end=8068
  _globals['_ETFENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_ETFENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_ETFENTRY_SECTORSENTRY']._serialized_start=6312
  _globals['_ETFENTRY_SECTORSENTRY']._serialized_end=6370
  _globals['_FUTUREENTRY']._serialized_start=8071
  _globals['_FUTUREENTRY']._serialized_end=9611
  _globals['_FUTUREENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_FUTUREENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_FUTUREENTRY_CATEGORYENTRY']._serialized_start=9552
  _globals['_FUTUREENTRY_CATEGORYENTRY']._serialized_end=9611
  _globals['_INDEXENTRY']._serialized_start=9614
  _globals['_INDEXENTRY']._serialized_end=11255
  _globals['_INDEXENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_INDEXENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_INDEXENTRY_COMPONENTSENTRY']._serialized_start=11194
  _globals['_INDEXENTRY_COMPONENTSENTRY']._serialized_end=11255
  _globals['_CRYPTOENTRY']._serialized_start=11258
  _globals['_CRYPTOENTRY']._serialized_end=12779
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_FOREXENTRY']._serialized_start=12782
  _globals['_FOREXENTRY']._serialized_end=14038
  _globals['_FOREXENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_FOREXENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_OPTIONENTRY']._serialized_start=14041
  _globals['_OPTIONENTRY']._serialized_end=15532
  _globals['_OPTIONENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_OPTIONENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_BONDENTRY']._serialized_start=15535
  _globals['_BONDENTRY']._serialized_end=17307
  _globals['_BONDENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_BONDENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_CDSENTRY']._serialized_start=17310
  _globals['_CDSENTRY']._serialized_end=18731
  _globals['_CDSENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_CDSENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_TICKSIZE']._serialized_start=18733
  _globals['_TICKSIZE']._serialized_end=18785
  _globals['_STATICDATASERVICE']._serialized_start=19755
  _globals['_STATICDATASERVICE']._serialized_end=19938
# @@protoc_insertion_point(module_scope)
