# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/type/shared/v2/trade.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/type/shared/v2/trade.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v2 import decimals_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_decimals__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,systemathics/apis/type/shared/v2/trade.proto\x12 systemathics.apis.type.shared.v2\x1a\x1egoogle/protobuf/wrappers.proto\x1a/systemathics/apis/type/shared/v2/decimals.proto\"\x9b\x03\n\x05Trade\x12<\n\nsize_value\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x00R\tsizeValue\x12i\n\x12size_decimal_value\x18\x02 \x01(\x0b\x32\x39.systemathics.apis.type.shared.v2.NullableUnsignedDecimalH\x00R\x10sizeDecimalValue\x12?\n\x0bprice_value\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueH\x01R\npriceValue\x12i\n\x13price_decimal_value\x18\x04 \x01(\x0b\x32\x37.systemathics.apis.type.shared.v2.NullableSignedDecimalH\x01R\x11priceDecimalValue\x12\x1c\n\tcondition\x18\x05 \x01(\tR\tcondition\x12\x0e\n\x02id\x18\x06 \x01(\tR\x02idB\x06\n\x04sizeB\x07\n\x05priceB\xd7\x01\n$com.systemathics.apis.type.shared.v2B\nTradeProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V2\xca\x02 Systemathics\\Apis\\Type\\Shared\\V2\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V2\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v2.trade_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v2B\nTradeProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V2\312\002 Systemathics\\Apis\\Type\\Shared\\V2\342\002,Systemathics\\Apis\\Type\\Shared\\V2\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V2'
  _globals['_TRADE']._serialized_start=164
  _globals['_TRADE']._serialized_end=575
# @@protoc_insertion_point(module_scope)
