# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/private/v1/identifier_mapping.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/private/v1/identifier_mapping.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from systemathics.apis.type.shared.v1 import memo_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_memo__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>systemathics/apis/services/private/v1/identifier_mapping.proto\x12%systemathics.apis.services.private.v1\x1a\x1cgoogle/api/annotations.proto\x1a+systemathics/apis/type/shared/v1/memo.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"V\n\x18IdentifierMappingRequest\x12:\n\x04memo\x18\x01 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.MemoR\x04memo\"i\n\x19IdentifierMappingResponse\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier2\xcc\x01\n\x18IdentifierMappingService\x12\xaf\x01\n\x11IdentifierMapping\x12?.systemathics.apis.services.private.v1.IdentifierMappingRequest\x1a@.systemathics.apis.services.private.v1.IdentifierMappingResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/identifiersB\xfe\x01\n)com.systemathics.apis.services.private.v1B\x16IdentifierMappingProtoP\x01\xa2\x02\x04SASP\xaa\x02%Systemathics.Apis.Services.Private.V1\xca\x02&Systemathics\\Apis\\Services\\Private_\\V1\xe2\x02\x32Systemathics\\Apis\\Services\\Private_\\V1\\GPBMetadata\xea\x02)Systemathics::Apis::Services::Private::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.private.v1.identifier_mapping_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.systemathics.apis.services.private.v1B\026IdentifierMappingProtoP\001\242\002\004SASP\252\002%Systemathics.Apis.Services.Private.V1\312\002&Systemathics\\Apis\\Services\\Private_\\V1\342\0022Systemathics\\Apis\\Services\\Private_\\V1\\GPBMetadata\352\002)Systemathics::Apis::Services::Private::V1'
  _globals['_IDENTIFIERMAPPINGSERVICE'].methods_by_name['IdentifierMapping']._loaded_options = None
  _globals['_IDENTIFIERMAPPINGSERVICE'].methods_by_name['IdentifierMapping']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/identifiers'
  _globals['_IDENTIFIERMAPPINGREQUEST']._serialized_start=231
  _globals['_IDENTIFIERMAPPINGREQUEST']._serialized_end=317
  _globals['_IDENTIFIERMAPPINGRESPONSE']._serialized_start=319
  _globals['_IDENTIFIERMAPPINGRESPONSE']._serialized_end=424
  _globals['_IDENTIFIERMAPPINGSERVICE']._serialized_start=427
  _globals['_IDENTIFIERMAPPINGSERVICE']._serialized_end=631
# @@protoc_insertion_point(module_scope)
