# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from systemathics.apis.services.tick_analytics.v2 import tick_bars_hp_pb2 as systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v2_dot_tick__bars__hp__pb2


class HpTickBarsServiceStub(object):
    """Called to request tick by tick bars data (high precision).
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HpTickBars = channel.unary_stream(
                '/systemathics.apis.services.tick_analytics.v2.HpTickBarsService/HpTickBars',
                request_serializer=systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v2_dot_tick__bars__hp__pb2.HpTickBarsRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v2_dot_tick__bars__hp__pb2.HpTickBarsResponse.FromString,
                )


class HpTickBarsServiceServicer(object):
    """Called to request tick by tick bars data (high precision).
    """

    def HpTickBars(self, request, context):
        """Gets tick by tick bars data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HpTickBarsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HpTickBars': grpc.unary_stream_rpc_method_handler(
                    servicer.HpTickBars,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v2_dot_tick__bars__hp__pb2.HpTickBarsRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v2_dot_tick__bars__hp__pb2.HpTickBarsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.tick_analytics.v2.HpTickBarsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class HpTickBarsService(object):
    """Called to request tick by tick bars data (high precision).
    """

    @staticmethod
    def HpTickBars(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.tick_analytics.v2.HpTickBarsService/HpTickBars',
            systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v2_dot_tick__bars__hp__pb2.HpTickBarsRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v2_dot_tick__bars__hp__pb2.HpTickBarsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
