# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/type/shared/v2/decimals.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/type/shared/v2/decimals.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/systemathics/apis/type/shared/v2/decimals.proto\x12 systemathics.apis.type.shared.v2\"m\n\rSignedDecimal\x12%\n\x0eunscaled_value\x18\x01 \x01(\x0cR\runscaledValue\x12\x14\n\x05scale\x18\x02 \x01(\x05R\x05scale\x12\x1f\n\x0bis_negative\x18\x03 \x01(\x08R\nisNegative\"m\n\x15NullableSignedDecimal\x12J\n\x05value\x18\x01 \x01(\x0b\x32/.systemathics.apis.type.shared.v2.SignedDecimalH\x00R\x05value\x88\x01\x01\x42\x08\n\x06_value\"N\n\x0fUnsignedDecimal\x12%\n\x0eunscaled_value\x18\x01 \x01(\x0cR\runscaledValue\x12\x14\n\x05scale\x18\x02 \x01(\x05R\x05scale\"q\n\x17NullableUnsignedDecimal\x12L\n\x05value\x18\x01 \x01(\x0b\x32\x31.systemathics.apis.type.shared.v2.UnsignedDecimalH\x00R\x05value\x88\x01\x01\x42\x08\n\x06_valueB\xda\x01\n$com.systemathics.apis.type.shared.v2B\rDecimalsProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V2\xca\x02 Systemathics\\Apis\\Type\\Shared\\V2\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V2\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v2.decimals_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v2B\rDecimalsProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V2\312\002 Systemathics\\Apis\\Type\\Shared\\V2\342\002,Systemathics\\Apis\\Type\\Shared\\V2\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V2'
  _globals['_SIGNEDDECIMAL']._serialized_start=85
  _globals['_SIGNEDDECIMAL']._serialized_end=194
  _globals['_NULLABLESIGNEDDECIMAL']._serialized_start=196
  _globals['_NULLABLESIGNEDDECIMAL']._serialized_end=305
  _globals['_UNSIGNEDDECIMAL']._serialized_start=307
  _globals['_UNSIGNEDDECIMAL']._serialized_end=385
  _globals['_NULLABLEUNSIGNEDDECIMAL']._serialized_start=387
  _globals['_NULLABLEUNSIGNEDDECIMAL']._serialized_end=500
# @@protoc_insertion_point(module_scope)
