# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/type/shared/v1/field.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/type/shared/v1/field.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,systemathics/apis/type/shared/v1/field.proto\x12 systemathics.apis.type.shared.v1*\xf1\x04\n\x05\x46ield\x12\x15\n\x11\x46IELD_UNSPECIFIED\x10\x00\x12\x14\n\x10\x46IELD_OPEN_PRICE\x10\x01\x12\x13\n\x0f\x46IELD_OPEN_SIZE\x10\x02\x12\x15\n\x11\x46IELD_CLOSE_PRICE\x10\x03\x12\x14\n\x10\x46IELD_CLOSE_SIZE\x10\x04\x12\x13\n\x0f\x46IELD_LOW_PRICE\x10\x05\x12\x12\n\x0e\x46IELD_LOW_SIZE\x10\x06\x12\x14\n\x10\x46IELD_HIGH_PRICE\x10\x07\x12\x13\n\x0f\x46IELD_HIGH_SIZE\x10\x08\x12\x15\n\x11\x46IELD_TRADE_PRICE\x10\t\x12\x14\n\x10\x46IELD_TRADE_SIZE\x10\n\x12\x1b\n\x17\x46IELD_TRADING_CONDITION\x10\x0b\x12\x15\n\x11\x46IELD_TRADE_COUNT\x10\x0c\x12\x19\n\x15\x46IELD_TRADE_OTC_PRICE\x10\r\x12\x18\n\x14\x46IELD_TRADE_OTC_SIZE\x10\x0e\x12\x19\n\x15\x46IELD_TRADE_OTC_COUNT\x10\x0f\x12\x10\n\x0c\x46IELD_VOLUME\x10\x10\x12\x17\n\x13\x46IELD_VWAP_OFFICIAL\x10\x11\x12\x19\n\x15\x46IELD_VWAP_ELECTRONIC\x10\x12\x12\x1b\n\x17\x46IELD_THEORETICAL_PRICE\x10\x13\x12\x1a\n\x16\x46IELD_THEORETICAL_SIZE\x10\x14\x12\x15\n\x11\x46IELD_UPPER_PRICE\x10\x15\x12\x15\n\x11\x46IELD_LOWER_PRICE\x10\x16\x12\x13\n\x0f\x46IELD_VARIATION\x10\x17\x12\x1e\n\x1a\x46IELD_VARIATION_PERCENTAGE\x10\x18\x12\x12\n\x0e\x46IELD_TRADE_ID\x10\x19\x42\xd7\x01\n$com.systemathics.apis.type.shared.v1B\nFieldProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.field_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\nFieldProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_FIELD']._serialized_start=83
  _globals['_FIELD']._serialized_end=708
# @@protoc_insertion_point(module_scope)
