# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/indices/v1/components.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/indices/v1/components.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6systemathics/apis/services/indices/v1/components.proto\x12%systemathics.apis.services.indices.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"a\n\x11\x43omponentsRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\"f\n\x12\x43omponentsResponse\x12P\n\ncomponents\x18\x01 \x03(\x0b\x32\x30.systemathics.apis.services.indices.v1.ComponentR\ncomponents\"q\n\tComponent\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06weight\x18\x02 \x01(\x01R\x06weight2\xba\x01\n\x11\x43omponentsService\x12\xa4\x01\n\nComponents\x12\x38.systemathics.apis.services.indices.v1.ComponentsRequest\x1a\x39.systemathics.apis.services.indices.v1.ComponentsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/staticdata/componentsB\xf5\x01\n)com.systemathics.apis.services.indices.v1B\x0f\x43omponentsProtoP\x01\xa2\x02\x04SASI\xaa\x02%Systemathics.Apis.Services.Indices.V1\xca\x02%Systemathics\\Apis\\Services\\Indices\\V1\xe2\x02\x31Systemathics\\Apis\\Services\\Indices\\V1\\GPBMetadata\xea\x02)Systemathics::Apis::Services::Indices::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.indices.v1.components_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.systemathics.apis.services.indices.v1B\017ComponentsProtoP\001\242\002\004SASI\252\002%Systemathics.Apis.Services.Indices.V1\312\002%Systemathics\\Apis\\Services\\Indices\\V1\342\0021Systemathics\\Apis\\Services\\Indices\\V1\\GPBMetadata\352\002)Systemathics::Apis::Services::Indices::V1'
  _globals['_COMPONENTSSERVICE'].methods_by_name['Components']._loaded_options = None
  _globals['_COMPONENTSSERVICE'].methods_by_name['Components']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/staticdata/components'
  _globals['_COMPONENTSREQUEST']._serialized_start=178
  _globals['_COMPONENTSREQUEST']._serialized_end=275
  _globals['_COMPONENTSRESPONSE']._serialized_start=277
  _globals['_COMPONENTSRESPONSE']._serialized_end=379
  _globals['_COMPONENT']._serialized_start=381
  _globals['_COMPONENT']._serialized_end=494
  _globals['_COMPONENTSSERVICE']._serialized_start=497
  _globals['_COMPONENTSSERVICE']._serialized_end=683
# @@protoc_insertion_point(module_scope)
